@@ -12,7 +12,7 @@
 #'
 #' @family randomizing operations
 #'
-#' @seealso \url{http://bedtools.readthedocs.org/en/latest/content/tools/random.html}
+#' @seealso \url{https://bedtools.readthedocs.io/en/latest/content/tools/random.html}
 #'
 #' @examples
 #' genome <- tibble::tribble(
@@ -45,5 +45,5 @@ bed_random <- function(genome, length = 1000, n = 1e6, seed = 0, sorted = TRUE)
     out <- bed_sort(out)
   }
 
-  out
+  as_tibble(out)
 }
