@@ -12,17 +12,17 @@ test_that("glyphs are rendered", {
 })
 
 test_that("glyph labels are applied", {
-  res <- bed_glyph(bed_merge(x, id = n()), label = "id")
+  res <- bed_glyph(bed_merge(x, id = dplyr::n()), label = "id")
   expect_equal(res$labels$label, "id")
 })
 
-a <- trbl_interval(
+a <- tibble::tribble(
   ~ chrom, ~ start, ~ end,
   "chr1", 25, 50,
   "chr1", 100, 125
 )
 
-b <- trbl_interval(
+b <- tibble::tribble(
   ~ chrom, ~ start, ~ end, ~ value,
   "chr1", 30, 75, 50
 )
